Browser Support | AdminLTE 3 Documentation
Description: AdminLTE v3 Documentaion

Browser Support | AdminLTE v3 Documentaion

# Browser Support

AdminLTE comes with the same browser support as Bootstrap 4.

> ##### Excerpt from Bootstrap’s official Documentation!

> Bootstrap supports the latest, stable releases of all major browsers and platforms. On Windows, we support Internet Explorer 10-11 / Microsoft Edge.

> For more details look here.

You can find our supported range of browsers and their versions in our .browserslistrc file:

    # https://github.com/browserslist/browserslist#readme

    >= 1%
    last 1 major version
    not dead
    Chrome >= 45
    Firefox >= 38
    Edge >= 12
    Explorer >= 10
    iOS >= 9
    Safari >= 9
    Android >= 4.4
    Opera >= 30